# coding=utf-8

from pytdx.parser.base import BaseParser
from pytdx.helper import get_datetime, get_volume, get_price
from collections import OrderedDict
import struct


class GetHistoryMinuteTimeData(BaseParser):

    def setParams(self, market, code, date):
        pkg = bytearray.fromhex("01 01 30 00 01 01 10 00 10 00 0c 24")
        code = code.encode("utf-8")
        pkg.extend(struct.pack("<IB9s", date, market, code))
        #pkg = bytearray.fromhex('01 01 30 00 01 01 10 00 10 00 0c 24 3b c8 33 01 2f 49 46 4c 30 00 38 ec 2d 00')
        self.send_pkg = pkg

    def parseResponse(self, body_buf):
        #        print('测试', body_buf)
        #        fileobj = open("//Users//wy//data//a.bin", 'wb')  # make partfile
        #        fileobj.write(body_buf)  # write data into partfile
        #        fileobj.close()
        pos = 0
        market, code, _, num = struct.unpack('<B9s8sH', body_buf[pos: pos + 20])
        pos += 20
#        print(market, code.decode(), num)
        result = []
        for i in range(num):

            (raw_time, price, avg_price, volume, amount) = struct.unpack("<HffII", body_buf[pos: pos + 18])

            pos += 18
            hour = raw_time // 60
            minute = raw_time % 60

            result.append(OrderedDict([
                ("hour", hour),
                ("minute", minute),
                ("price", price),
                ("avg_price", avg_price),
                ("volume", volume),
                ("open_interest", amount),
            ]))

        return result


if __name__ == '__main__':
    from pytdx.exhq import TdxExHq_API
    api = TdxExHq_API()
    cmd = GetHistoryMinuteTimeData(api)
    cmd.setParams(8, "10000843", 20180811)
    print(cmd.send_pkg)



# coding=utf-8

from pytdx.parser.base import BaseParser
from pytdx.helper import get_datetime, get_volume, get_price
from collections import OrderedDict
import struct


class SetupCmd1(BaseParser):
    def setup(self):
        self.send_pkg = bytearray.fromhex(u'0c 02 18 93 00 01 03 00 03 00 0d 00 01')

    def parseResponse(self, body_buf):
        return body_buf


class SetupCmd2(BaseParser):
    def setup(self):
        self.send_pkg = bytearray.fromhex(u'0c 02 18 94 00 01 03 00 03 00 0d 00 02')

    def parseResponse(self, body_buf):
        return body_buf


class SetupCmd3(BaseParser):

    def setup(self):
        self.send_pkg = bytearray.fromhex(u'0c 03 18 99 00 01 20 00 20 00 db 0f d5'
                                      u'd0 c9 cc d6 a4 a8 af 00 00 00 8f c2 25'
                                      u'40 13 00 00 d5 00 c9 cc bd f0 d7 ea 00'
                                      u'00 00 02')

    def parseResponse(self, body_buf):
        return body_buf


# coding=utf-8

from pytdx.parser.base import BaseParser

# Use this parser for testing


class RawParser(BaseParser):

    def setParams(self, pkg):
        self.send_pkg = pkg

    def parseResponse(self, body_buf):
        return body_buf



# coding=utf-8

from pytdx.parser.base import BaseParser
from pytdx.helper import get_datetime, get_volume, get_price
from collections import OrderedDict
import struct


class ExSetupCmd1(BaseParser):

    def setup(self):
        self.send_pkg = bytearray.fromhex("01 01 48 65 00 01 52 00 52 00 54 24 1f 32 c6 e5"
                                            "d5 3d fb 41 1f 32 c6 e5 d5 3d fb 41 1f 32 c6 e5"
                                            "d5 3d fb 41 1f 32 c6 e5 d5 3d fb 41 1f 32 c6 e5"
                                            "d5 3d fb 41 1f 32 c6 e5 d5 3d fb 41 1f 32 c6 e5"
                                            "d5 3d fb 41 1f 32 c6 e5 d5 3d fb 41 cc e1 6d ff"
                                            "d5 ba 3f b8 cb c5 7a 05 4f 77 48 ea")

    def parseResponse(self, body_buf):
        pass


# coding=utf-8

from pytdx.parser.base import BaseParser
from pytdx.helper import get_datetime, get_volume, get_price
from collections import OrderedDict
import struct

"""
tradex 结果

﻿        7、查询分时...

时间    价格    均价    成交量  成交额
09:30   3706.199951     3706.199951     27      13336
09:31   3705.199951     3705.910400     11      13335
09:32   3704.600098     3705.473633     19      13328
09:33   3701.399902     3704.717041     13      13324
09:34   3700.800049     3704.556152     3       13323
09:35   3699.800049     3703.379395     24      13321
09:36   3695.800049     3702.544922     12      13319
09:37   3700.600098     3702.510010     2       13318
"""


class GetMinuteTimeData(BaseParser):

    def setParams(self, market, code):
        pkg = bytearray.fromhex("01 07 08 00 01 01 0c 00 0c 00 0b 24")
        code = code.encode("utf-8")
        pkg.extend(struct.pack('<B9s', market, code))
        self.send_pkg = pkg


    def parseResponse(self, body_buf):
        pos = 0
        market, code, num = struct.unpack('<B9sH', body_buf[pos: pos+12])
        pos += 12

        result = []
        for i in range(num):

            (raw_time, price, avg_price, volume, amount) = struct.unpack("<HffII", body_buf[pos: pos+18])
            pos += 18
            hour = raw_time // 60
            minute = raw_time % 60

            result.append(OrderedDict([
                ("hour", hour),
                ("minute", minute),
                ("price", price),
                ("avg_price", avg_price),
                ("volume", volume),
                ("open_interest", amount),
            ]))

        return result


#!/usr/bin/env python

from setuptools import setup, find_packages
import os

PYTDX_CYTHON = os.getenv("PYTDX_CYTHON", None)

if PYTDX_CYTHON:
    from Cython.Build import cythonize
    cythonkw = {
        "ext_modules": cythonize(
            ["pytdx/reader/c_gbbq_reader.pyx",
             'pytdx/parser/get_security_quotes.py',
             'pytdx/parser/base.py',
             'pytdx/helper.py',
             'pytdx/hq.py',
             'pytdx/base_socket_client.py',
             ])
    }
else:
    cythonkw = {}
try:
    import pypandoc
    long_description = pypandoc.convert('README.md', 'rst')
except (IOError, ImportError):
    long_description = ''


setup(
    name='pytdx',
    version='1.55',
    description='A Python Interface to TDX protocol',
    long_description=long_description,
    author='RainX<Jing Xu>',
    author_email='i@rainx.cc',
    url='https://github.com/rainx/pytdx',
    packages=find_packages(),
    install_requires=[
            'click',
            'pandas',
            'six',
            'cryptography',
    ],
    entry_points={
          'console_scripts': [
              'hqget=pytdx.bin.hqget:main',
              'hqreader=pytdx.bin.hqreader:main',
              'get_tts=pytdx.bin.get_tdx_trader_server:main',
              'hqbenchmark=pytdx.bin.hqbenchmark:main',
          ]
      },
    **cythonkw
    )

